@@ -202,6 +202,7 @@ def main_impl():
         else:
             LOGGER.critical("Catalog file not specified")
     except Exception as e:
+        LOGGER.warn("Exception raised: %s", e)
         source.delete_credentials_file(conn_config)
         raise e
     source.delete_credentials_file(conn_config)
@@ -244,6 +245,7 @@ class BigQuerySourceConnector(C8Connector):
             config = source.create_credentials_file(config)
             discover(config)
         except Exception as e:
+            LOGGER.warn("Exception raised: %s", e)
             source.delete_credentials_file(config)
             raise e
         source.delete_credentials_file(config)
@@ -253,7 +255,7 @@ class BigQuerySourceConnector(C8Connector):
         config = self.get_config(integration)
         try:
             config = source.create_credentials_file(config)
-            streams = discover(config)
+            streams = discover(config)['streams']
             results = []
             for stream in streams:
                 s_attribs = []
@@ -277,6 +279,7 @@ class BigQuerySourceConnector(C8Connector):
                     data=data)
                 )
         except Exception as e:
+            LOGGER.warn("Exception raised: %s", e)
             source.delete_credentials_file(config)
             raise e
         source.delete_credentials_file(config)
@@ -287,7 +290,7 @@ class BigQuerySourceConnector(C8Connector):
         config = self.get_config(integration)
         try:
             config = source.create_credentials_file(config)
-            streams = discover(config)
+            streams = discover(config)['streams']
             results = []
             for stream in streams:
                 s_attribs = []
@@ -306,6 +309,7 @@ class BigQuerySourceConnector(C8Connector):
                     s_attribs.append(SchemaAttribute(k, self.get_attribute_type(t)))
                 results.append(Schema(stream['stream'], s_attribs))
         except Exception as e:
+            LOGGER.warn("Exception raised: %s", e)
             source.delete_credentials_file(config)
             raise e
         source.delete_credentials_file(config)
